# Generated by roxygen2: do not edit by hand

export(AddressProvider)
export(AddressProvider_en_GB)
export(AddressProvider_en_NZ)
export(AddressProvider_en_US)
export(AddressProvider_nl_NL)
export(BaseProvider)
export(ColorProvider_en_US)
export(ColorProvider_uk_UA)
export(CompanyProvider)
export(CompanyProvider_bg_BG)
export(CompanyProvider_cs_CZ)
export(CompanyProvider_de_DE)
export(CompanyProvider_en_US)
export(CompanyProvider_es_MX)
export(CompanyProvider_fa_IR)
export(CompanyProvider_fr_FR)
export(CompanyProvider_hr_HR)
export(CompanyProvider_it_IT)
export(CoordinateProvider)
export(CreditCardProvider)
export(CurrencyProvider)
export(DOIProvider)
export(DateTimeProvider)
export(ElementProvider)
export(ElementProvider_en_US)
export(ElementProvider_nl_NL)
export(FileProvider)
export(FileProvider_en_US)
export(FraudsterClient)
export(ISBNProvider)
export(InternetProvider)
export(InternetProvider_bg_BG)
export(InternetProvider_cs_CZ)
export(InternetProvider_de_DE)
export(InternetProvider_en_AU)
export(InternetProvider_en_NZ)
export(InternetProvider_en_US)
export(InternetProvider_fa_IR)
export(InternetProvider_fr_FR)
export(InternetProvider_hr_HR)
export(JobProvider)
export(JobProvider_da_DK)
export(JobProvider_en_US)
export(JobProvider_fa_IR)
export(JobProvider_fi_FI)
export(JobProvider_fr_CH)
export(JobProvider_fr_FR)
export(JobProvider_hr_HR)
export(JobProvider_nl_NL)
export(JobProvider_pl_PL)
export(JobProvider_ru_RU)
export(JobProvider_uk_UA)
export(JobProvider_zh_TW)
export(LoremProvider)
export(LoremProvider_ar_AA)
export(LoremProvider_el_GR)
export(LoremProvider_en_US)
export(LoremProvider_he_IL)
export(LoremProvider_ja_JP)
export(LoremProvider_la)
export(LoremProvider_ru_RU)
export(LoremProvider_zh_CN)
export(LoremProvider_zh_TW)
export(MiscProvider)
export(MissingDataProvider)
export(NumericsProvider)
export(PersonProvider)
export(PersonProvider_bg_BG)
export(PersonProvider_cs_CZ)
export(PersonProvider_da_DK)
export(PersonProvider_de_AT)
export(PersonProvider_de_DE)
export(PersonProvider_en_GB)
export(PersonProvider_en_NZ)
export(PersonProvider_en_US)
export(PersonProvider_es_ES)
export(PersonProvider_es_MX)
export(PersonProvider_fa_IR)
export(PersonProvider_fi_FI)
export(PersonProvider_fr_CH)
export(PersonProvider_fr_FR)
export(PersonProvider_hr_HR)
export(PersonProvider_it_IT)
export(PersonProvider_ja_JP)
export(PersonProvider_ko_KR)
export(PersonProvider_lt_LT)
export(PersonProvider_lv_LV)
export(PersonProvider_ne_NP)
export(PersonProvider_nl_NL)
export(PersonProvider_no_NO)
export(PersonProvider_pl_PL)
export(PhoneNumberProvider)
export(PhoneNumberProvider_bg_BG)
export(PhoneNumberProvider_bs_BA)
export(PhoneNumberProvider_cs_CZ)
export(PhoneNumberProvider_da_DK)
export(PhoneNumberProvider_de_DE)
export(PhoneNumberProvider_dk_DK)
export(PhoneNumberProvider_el_GR)
export(PhoneNumberProvider_en_AU)
export(PhoneNumberProvider_en_CA)
export(PhoneNumberProvider_en_GB)
export(PhoneNumberProvider_en_NZ)
export(PhoneNumberProvider_en_US)
export(PhoneNumberProvider_es_ES)
export(PhoneNumberProvider_es_MX)
export(PhoneNumberProvider_es_PE)
export(PhoneNumberProvider_fa_IR)
export(PhoneNumberProvider_fi_FI)
export(PhoneNumberProvider_fr_CH)
export(PhoneNumberProvider_fr_FR)
export(PhoneNumberProvider_he_IL)
export(PhoneNumberProvider_hi_IN)
export(PhoneNumberProvider_hr_HR)
export(PhoneNumberProvider_hu_HU)
export(PhoneNumberProvider_id_ID)
export(PhoneNumberProvider_it_IT)
export(PhoneNumberProvider_ja_JP)
export(PhoneNumberProvider_ko_KR)
export(PhoneNumberProvider_lt_LT)
export(PhoneNumberProvider_lv_LV)
export(PhoneNumberProvider_ne_NP)
export(PhoneNumberProvider_nl_BE)
export(PhoneNumberProvider_nl_NL)
export(PhoneNumberProvider_nn_NO)
export(PhoneNumberProvider_no_NO)
export(PhoneNumberProvider_pl_PL)
export(PhoneNumberProvider_pt_BR)
export(PhoneNumberProvider_pt_PT)
export(PhoneNumberProvider_ru_RU)
export(PhoneNumberProvider_sk_SK)
export(PhoneNumberProvider_sv_SE)
export(PhoneNumberProvider_th_TH)
export(PhoneNumberProvider_tr_TR)
export(PhoneNumberProvider_uk_UA)
export(PhoneNumberProvider_zh_TW)
export(SSNProvider)
export(SSNProvider_en_US)
export(SSNProvider_nl_NL)
export(SequenceProvider)
export(TaxonomyProvider)
export(TaxonomyProvider_en_US)
export(UserAgentProvider)
export(UserAgentProvider_en_US)
export(ch_beta)
export(ch_color_name)
export(ch_company)
export(ch_credit_card_number)
export(ch_credit_card_provider)
export(ch_credit_card_security_code)
export(ch_currency)
export(ch_date_time)
export(ch_doi)
export(ch_double)
export(ch_element_element)
export(ch_element_symbol)
export(ch_gene_sequence)
export(ch_generate)
export(ch_hex_color)
export(ch_integer)
export(ch_job)
export(ch_lat)
export(ch_lnorm)
export(ch_lon)
export(ch_missing)
export(ch_name)
export(ch_norm)
export(ch_phone_number)
export(ch_position)
export(ch_rgb_color)
export(ch_rgb_css_color)
export(ch_safe_color_name)
export(ch_safe_hex_color)
export(ch_ssn)
export(ch_taxonomic_epithet)
export(ch_taxonomic_genus)
export(ch_taxonomic_species)
export(ch_timezone)
export(ch_unif)
export(ch_unix_time)
export(charlatan_locales)
export(charlatan_settings)
export(fraudster)
export(subclass)
importFrom(R6,R6Class)
importFrom(tibble,as_tibble)
importFrom(whisker,whisker.render)
